@@ -210,6 +210,7 @@ const struct s2n_record_algorithm s2n_tls13_record_alg_chacha20_poly1305 = {
 struct s2n_cipher_suite s2n_null_cipher_suite = {
     .available = 1,
     .name = "TLS_NULL_WITH_NULL_NULL",
+    .iana_name = "TLS_NULL_WITH_NULL_NULL",
     .iana_value = { TLS_NULL_WITH_NULL_NULL },
     .key_exchange_alg = &s2n_rsa,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -219,6 +220,7 @@ struct s2n_cipher_suite s2n_null_cipher_suite = {
 struct s2n_cipher_suite s2n_rsa_with_rc4_128_md5 = /* 0x00,0x04 */ {
     .available = 0,
     .name = "RC4-MD5",
+    .iana_name = "TLS_RSA_WITH_RC4_128_MD5",
     .iana_value = { TLS_RSA_WITH_RC4_128_MD5 },
     .key_exchange_alg = &s2n_rsa,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -233,6 +235,7 @@ struct s2n_cipher_suite s2n_rsa_with_rc4_128_md5 = /* 0x00,0x04 */ {
 struct s2n_cipher_suite s2n_rsa_with_rc4_128_sha = /* 0x00,0x05 */ {
     .available = 0,
     .name = "RC4-SHA",
+    .iana_name = "TLS_RSA_WITH_RC4_128_SHA",
     .iana_value = { TLS_RSA_WITH_RC4_128_SHA },
     .key_exchange_alg = &s2n_rsa,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -247,6 +250,7 @@ struct s2n_cipher_suite s2n_rsa_with_rc4_128_sha = /* 0x00,0x05 */ {
 struct s2n_cipher_suite s2n_rsa_with_3des_ede_cbc_sha = /* 0x00,0x0A */ {
     .available = 0,
     .name = "DES-CBC3-SHA",
+    .iana_name = "TLS_RSA_WITH_3DES_EDE_CBC_SHA",
     .iana_value = { TLS_RSA_WITH_3DES_EDE_CBC_SHA },
     .key_exchange_alg = &s2n_rsa,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -261,6 +265,7 @@ struct s2n_cipher_suite s2n_rsa_with_3des_ede_cbc_sha = /* 0x00,0x0A */ {
 struct s2n_cipher_suite s2n_dhe_rsa_with_3des_ede_cbc_sha = /* 0x00,0x16 */ {
     .available = 0,
     .name = "DHE-RSA-DES-CBC3-SHA",
+    .iana_name = "TLS_DHE_RSA_WITH_3DES_EDE_CBC_SHA",
     .iana_value = { TLS_DHE_RSA_WITH_3DES_EDE_CBC_SHA },
     .key_exchange_alg = &s2n_dhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -275,6 +280,7 @@ struct s2n_cipher_suite s2n_dhe_rsa_with_3des_ede_cbc_sha = /* 0x00,0x16 */ {
 struct s2n_cipher_suite s2n_rsa_with_aes_128_cbc_sha = /* 0x00,0x2F */ {
     .available = 0,
     .name = "AES128-SHA",
+    .iana_name = "TLS_RSA_WITH_AES_128_CBC_SHA",
     .iana_value = { TLS_RSA_WITH_AES_128_CBC_SHA },
     .key_exchange_alg = &s2n_rsa,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -289,6 +295,7 @@ struct s2n_cipher_suite s2n_rsa_with_aes_128_cbc_sha = /* 0x00,0x2F */ {
 struct s2n_cipher_suite s2n_dhe_rsa_with_aes_128_cbc_sha = /* 0x00,0x33 */ {
     .available = 0,
     .name = "DHE-RSA-AES128-SHA",
+    .iana_name = "TLS_DHE_RSA_WITH_AES_128_CBC_SHA",
     .iana_value = { TLS_DHE_RSA_WITH_AES_128_CBC_SHA },
     .key_exchange_alg = &s2n_dhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -303,6 +310,7 @@ struct s2n_cipher_suite s2n_dhe_rsa_with_aes_128_cbc_sha = /* 0x00,0x33 */ {
 struct s2n_cipher_suite s2n_rsa_with_aes_256_cbc_sha = /* 0x00,0x35 */ {
     .available = 0,
     .name = "AES256-SHA",
+    .iana_name = "TLS_RSA_WITH_AES_256_CBC_SHA",
     .iana_value = { TLS_RSA_WITH_AES_256_CBC_SHA },
     .key_exchange_alg = &s2n_rsa,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -317,6 +325,7 @@ struct s2n_cipher_suite s2n_rsa_with_aes_256_cbc_sha = /* 0x00,0x35 */ {
 struct s2n_cipher_suite s2n_dhe_rsa_with_aes_256_cbc_sha = /* 0x00,0x39 */ {
     .available = 0,
     .name = "DHE-RSA-AES256-SHA",
+    .iana_name = "TLS_DHE_RSA_WITH_AES_256_CBC_SHA",
     .iana_value = { TLS_DHE_RSA_WITH_AES_256_CBC_SHA },
     .key_exchange_alg = &s2n_dhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -331,6 +340,7 @@ struct s2n_cipher_suite s2n_dhe_rsa_with_aes_256_cbc_sha = /* 0x00,0x39 */ {
 struct s2n_cipher_suite s2n_rsa_with_aes_128_cbc_sha256 = /* 0x00,0x3C */ {
     .available = 0,
     .name = "AES128-SHA256",
+    .iana_name = "TLS_RSA_WITH_AES_128_CBC_SHA256",
     .iana_value = { TLS_RSA_WITH_AES_128_CBC_SHA256 },
     .key_exchange_alg = &s2n_rsa,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -345,6 +355,7 @@ struct s2n_cipher_suite s2n_rsa_with_aes_128_cbc_sha256 = /* 0x00,0x3C */ {
 struct s2n_cipher_suite s2n_rsa_with_aes_256_cbc_sha256 = /* 0x00,0x3D */ {
     .available = 0,
     .name = "AES256-SHA256",
+    .iana_name = "TLS_RSA_WITH_AES_256_CBC_SHA256",
     .iana_value = { TLS_RSA_WITH_AES_256_CBC_SHA256 },
     .key_exchange_alg = &s2n_rsa,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -359,6 +370,7 @@ struct s2n_cipher_suite s2n_rsa_with_aes_256_cbc_sha256 = /* 0x00,0x3D */ {
 struct s2n_cipher_suite s2n_dhe_rsa_with_aes_128_cbc_sha256 = /* 0x00,0x67 */ {
     .available = 0,
     .name = "DHE-RSA-AES128-SHA256",
+    .iana_name = "TLS_DHE_RSA_WITH_AES_128_CBC_SHA256",
     .iana_value = { TLS_DHE_RSA_WITH_AES_128_CBC_SHA256 },
     .key_exchange_alg = &s2n_dhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -373,6 +385,7 @@ struct s2n_cipher_suite s2n_dhe_rsa_with_aes_128_cbc_sha256 = /* 0x00,0x67 */ {
 struct s2n_cipher_suite s2n_dhe_rsa_with_aes_256_cbc_sha256 = /* 0x00,0x6B */ {
     .available = 0,
     .name = "DHE-RSA-AES256-SHA256",
+    .iana_name = "TLS_DHE_RSA_WITH_AES_256_CBC_SHA256",
     .iana_value = { TLS_DHE_RSA_WITH_AES_256_CBC_SHA256 },
     .key_exchange_alg = &s2n_dhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -387,6 +400,7 @@ struct s2n_cipher_suite s2n_dhe_rsa_with_aes_256_cbc_sha256 = /* 0x00,0x6B */ {
 struct s2n_cipher_suite s2n_rsa_with_aes_128_gcm_sha256 = /* 0x00,0x9C */ {
     .available = 0,
     .name = "AES128-GCM-SHA256",
+    .iana_name = "TLS_RSA_WITH_AES_128_GCM_SHA256",
     .iana_value = { TLS_RSA_WITH_AES_128_GCM_SHA256 },
     .key_exchange_alg = &s2n_rsa,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -401,6 +415,7 @@ struct s2n_cipher_suite s2n_rsa_with_aes_128_gcm_sha256 = /* 0x00,0x9C */ {
 struct s2n_cipher_suite s2n_rsa_with_aes_256_gcm_sha384 = /* 0x00,0x9D */ {
     .available = 0,
     .name = "AES256-GCM-SHA384",
+    .iana_name = "TLS_RSA_WITH_AES_256_GCM_SHA384",
     .iana_value = { TLS_RSA_WITH_AES_256_GCM_SHA384 },
     .key_exchange_alg = &s2n_rsa,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -415,6 +430,7 @@ struct s2n_cipher_suite s2n_rsa_with_aes_256_gcm_sha384 = /* 0x00,0x9D */ {
 struct s2n_cipher_suite s2n_dhe_rsa_with_aes_128_gcm_sha256 = /* 0x00,0x9E */ {
     .available = 0,
     .name = "DHE-RSA-AES128-GCM-SHA256",
+    .iana_name = "TLS_DHE_RSA_WITH_AES_128_GCM_SHA256",
     .iana_value = { TLS_DHE_RSA_WITH_AES_128_GCM_SHA256 },
     .key_exchange_alg = &s2n_dhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -429,6 +445,7 @@ struct s2n_cipher_suite s2n_dhe_rsa_with_aes_128_gcm_sha256 = /* 0x00,0x9E */ {
 struct s2n_cipher_suite s2n_dhe_rsa_with_aes_256_gcm_sha384 = /* 0x00,0x9F */ {
     .available = 0,
     .name = "DHE-RSA-AES256-GCM-SHA384",
+    .iana_name = "TLS_DHE_RSA_WITH_AES_256_GCM_SHA384",
     .iana_value = { TLS_DHE_RSA_WITH_AES_256_GCM_SHA384 },
     .key_exchange_alg = &s2n_dhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -443,6 +460,7 @@ struct s2n_cipher_suite s2n_dhe_rsa_with_aes_256_gcm_sha384 = /* 0x00,0x9F */ {
 struct s2n_cipher_suite s2n_ecdhe_ecdsa_with_aes_128_cbc_sha = /* 0xC0,0x09 */ {
     .available = 0,
     .name = "ECDHE-ECDSA-AES128-SHA",
+    .iana_name = "TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA",
     .iana_value = { TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_ECDSA,
@@ -457,6 +475,7 @@ struct s2n_cipher_suite s2n_ecdhe_ecdsa_with_aes_128_cbc_sha = /* 0xC0,0x09 */ {
 struct s2n_cipher_suite s2n_ecdhe_ecdsa_with_aes_256_cbc_sha = /* 0xC0,0x0A */ {
     .available = 0,
     .name = "ECDHE-ECDSA-AES256-SHA",
+    .iana_name = "TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA",
     .iana_value = { TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_ECDSA,
@@ -471,6 +490,7 @@ struct s2n_cipher_suite s2n_ecdhe_ecdsa_with_aes_256_cbc_sha = /* 0xC0,0x0A */ {
 struct s2n_cipher_suite s2n_ecdhe_rsa_with_rc4_128_sha = /* 0xC0,0x11 */ {
     .available = 0,
     .name = "ECDHE-RSA-RC4-SHA",
+    .iana_name = "TLS_ECDHE_RSA_WITH_RC4_128_SHA",
     .iana_value = { TLS_ECDHE_RSA_WITH_RC4_128_SHA },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -485,6 +505,7 @@ struct s2n_cipher_suite s2n_ecdhe_rsa_with_rc4_128_sha = /* 0xC0,0x11 */ {
 struct s2n_cipher_suite s2n_ecdhe_rsa_with_3des_ede_cbc_sha = /* 0xC0,0x12 */ {
     .available = 0,
     .name = "ECDHE-RSA-DES-CBC3-SHA",
+    .iana_name = "TLS_ECDHE_RSA_WITH_3DES_EDE_CBC_SHA",
     .iana_value = { TLS_ECDHE_RSA_WITH_3DES_EDE_CBC_SHA },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -499,6 +520,7 @@ struct s2n_cipher_suite s2n_ecdhe_rsa_with_3des_ede_cbc_sha = /* 0xC0,0x12 */ {
 struct s2n_cipher_suite s2n_ecdhe_rsa_with_aes_128_cbc_sha = /* 0xC0,0x13 */ {
     .available = 0,
     .name = "ECDHE-RSA-AES128-SHA",
+    .iana_name = "TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA",
     .iana_value = { TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -513,6 +535,7 @@ struct s2n_cipher_suite s2n_ecdhe_rsa_with_aes_128_cbc_sha = /* 0xC0,0x13 */ {
 struct s2n_cipher_suite s2n_ecdhe_rsa_with_aes_256_cbc_sha = /* 0xC0,0x14 */ {
     .available = 0,
     .name = "ECDHE-RSA-AES256-SHA",
+    .iana_name = "TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA",
     .iana_value = { TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -527,6 +550,7 @@ struct s2n_cipher_suite s2n_ecdhe_rsa_with_aes_256_cbc_sha = /* 0xC0,0x14 */ {
 struct s2n_cipher_suite s2n_ecdhe_ecdsa_with_aes_128_cbc_sha256 = /* 0xC0,0x23 */ {
     .available = 0,
     .name = "ECDHE-ECDSA-AES128-SHA256",
+    .iana_name = "TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256",
     .iana_value = { TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256 },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_ECDSA,
@@ -541,6 +565,7 @@ struct s2n_cipher_suite s2n_ecdhe_ecdsa_with_aes_128_cbc_sha256 = /* 0xC0,0x23 *
 struct s2n_cipher_suite s2n_ecdhe_ecdsa_with_aes_256_cbc_sha384 = /* 0xC0,0x24 */ {
     .available = 0,
     .name = "ECDHE-ECDSA-AES256-SHA384",
+    .iana_name = "TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384",
     .iana_value = { TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384 },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_ECDSA,
@@ -555,6 +580,7 @@ struct s2n_cipher_suite s2n_ecdhe_ecdsa_with_aes_256_cbc_sha384 = /* 0xC0,0x24 *
 struct s2n_cipher_suite s2n_ecdhe_rsa_with_aes_128_cbc_sha256 = /* 0xC0,0x27 */ {
     .available = 0,
     .name = "ECDHE-RSA-AES128-SHA256",
+    .iana_name = "TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256",
     .iana_value = { TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256 },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -569,6 +595,7 @@ struct s2n_cipher_suite s2n_ecdhe_rsa_with_aes_128_cbc_sha256 = /* 0xC0,0x27 */
 struct s2n_cipher_suite s2n_ecdhe_rsa_with_aes_256_cbc_sha384 = /* 0xC0,0x28 */ {
     .available = 0,
     .name = "ECDHE-RSA-AES256-SHA384",
+    .iana_name = "TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384",
     .iana_value = { TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384 },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -583,6 +610,7 @@ struct s2n_cipher_suite s2n_ecdhe_rsa_with_aes_256_cbc_sha384 = /* 0xC0,0x28 */
 struct s2n_cipher_suite s2n_ecdhe_ecdsa_with_aes_128_gcm_sha256 = /* 0xC0,0x2B */ {
     .available = 0,
     .name = "ECDHE-ECDSA-AES128-GCM-SHA256",
+    .iana_name = "TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256",
     .iana_value = { TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256 },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_ECDSA,
@@ -597,6 +625,7 @@ struct s2n_cipher_suite s2n_ecdhe_ecdsa_with_aes_128_gcm_sha256 = /* 0xC0,0x2B *
 struct s2n_cipher_suite s2n_ecdhe_ecdsa_with_aes_256_gcm_sha384 = /* 0xC0,0x2C */ {
     .available = 0,
     .name = "ECDHE-ECDSA-AES256-GCM-SHA384",
+    .iana_name = "TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384",
     .iana_value = { TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384 },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_ECDSA,
@@ -611,6 +640,7 @@ struct s2n_cipher_suite s2n_ecdhe_ecdsa_with_aes_256_gcm_sha384 = /* 0xC0,0x2C *
 struct s2n_cipher_suite s2n_ecdhe_rsa_with_aes_128_gcm_sha256 = /* 0xC0,0x2F */ {
     .available = 0,
     .name = "ECDHE-RSA-AES128-GCM-SHA256",
+    .iana_name = "TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256",
     .iana_value = { TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256 },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -625,6 +655,7 @@ struct s2n_cipher_suite s2n_ecdhe_rsa_with_aes_128_gcm_sha256 = /* 0xC0,0x2F */
 struct s2n_cipher_suite s2n_ecdhe_rsa_with_aes_256_gcm_sha384 = /* 0xC0,0x30 */ {
     .available = 0,
     .name = "ECDHE-RSA-AES256-GCM-SHA384",
+    .iana_name = "TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384",
     .iana_value = { TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384 },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -639,6 +670,7 @@ struct s2n_cipher_suite s2n_ecdhe_rsa_with_aes_256_gcm_sha384 = /* 0xC0,0x30 */
 struct s2n_cipher_suite s2n_ecdhe_rsa_with_chacha20_poly1305_sha256 = /* 0xCC,0xA8 */ {
     .available = 0,
     .name = "ECDHE-RSA-CHACHA20-POLY1305",
+    .iana_name = "TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256",
     .iana_value = { TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256 },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -653,6 +685,7 @@ struct s2n_cipher_suite s2n_ecdhe_rsa_with_chacha20_poly1305_sha256 = /* 0xCC,0x
 struct s2n_cipher_suite s2n_ecdhe_ecdsa_with_chacha20_poly1305_sha256 = /* 0xCC,0xA9 */ {
     .available = 0,
     .name = "ECDHE-ECDSA-CHACHA20-POLY1305",
+    .iana_name = "TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256",
     .iana_value = { TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256 },
     .key_exchange_alg = &s2n_ecdhe,
     .auth_method = S2N_AUTHENTICATION_ECDSA,
@@ -667,6 +700,7 @@ struct s2n_cipher_suite s2n_ecdhe_ecdsa_with_chacha20_poly1305_sha256 = /* 0xCC,
 struct s2n_cipher_suite s2n_dhe_rsa_with_chacha20_poly1305_sha256 = /* 0xCC,0xAA */ {
     .available = 0,
     .name = "DHE-RSA-CHACHA20-POLY1305",
+    .iana_name = "TLS_DHE_RSA_WITH_CHACHA20_POLY1305_SHA256",
     .iana_value = { TLS_DHE_RSA_WITH_CHACHA20_POLY1305_SHA256 },
     .key_exchange_alg = &s2n_dhe,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -683,6 +717,7 @@ struct s2n_cipher_suite s2n_dhe_rsa_with_chacha20_poly1305_sha256 = /* 0xCC,0xAA
 struct s2n_cipher_suite s2n_ecdhe_kyber_rsa_with_aes_256_gcm_sha384 = /* 0xFF, 0x0C */ {
     .available = 0,
     .name = "ECDHE-KYBER-RSA-AES256-GCM-SHA384",
+    .iana_name = "TLS_ECDHE_KYBER_RSA_WITH_AES_256_GCM_SHA384",
     .iana_value = { TLS_ECDHE_KYBER_RSA_WITH_AES_256_GCM_SHA384 },
     .key_exchange_alg = &s2n_hybrid_ecdhe_kem,
     .auth_method = S2N_AUTHENTICATION_RSA,
@@ -697,6 +732,7 @@ struct s2n_cipher_suite s2n_ecdhe_kyber_rsa_with_aes_256_gcm_sha384 = /* 0xFF, 0
 struct s2n_cipher_suite s2n_tls13_aes_128_gcm_sha256 = {
     .available = 0,
     .name = "TLS_AES_128_GCM_SHA256",
+    .iana_name = "TLS_AES_128_GCM_SHA256",
     .iana_value = { TLS_AES_128_GCM_SHA256 },
     .key_exchange_alg = &s2n_tls13_kex,
     .auth_method = S2N_AUTHENTICATION_METHOD_TLS13,
@@ -711,6 +747,7 @@ struct s2n_cipher_suite s2n_tls13_aes_128_gcm_sha256 = {
 struct s2n_cipher_suite s2n_tls13_aes_256_gcm_sha384 = {
     .available = 0,
     .name = "TLS_AES_256_GCM_SHA384",
+    .iana_name = "TLS_AES_256_GCM_SHA384",
     .iana_value = { TLS_AES_256_GCM_SHA384 },
     .key_exchange_alg = &s2n_tls13_kex,
     .auth_method = S2N_AUTHENTICATION_METHOD_TLS13,
@@ -725,6 +762,7 @@ struct s2n_cipher_suite s2n_tls13_aes_256_gcm_sha384 = {
 struct s2n_cipher_suite s2n_tls13_chacha20_poly1305_sha256 = {
     .available = 0,
     .name = "TLS_CHACHA20_POLY1305_SHA256",
+    .iana_name = "TLS_CHACHA20_POLY1305_SHA256",
     .iana_value = { TLS_CHACHA20_POLY1305_SHA256 },
     .key_exchange_alg = &s2n_tls13_kex,
     .auth_method = S2N_AUTHENTICATION_METHOD_TLS13,
@@ -1097,16 +1135,16 @@ int s2n_set_cipher_as_client(struct s2n_connection *conn, uint8_t wire[S2N_TLS_C
      * Ensure that the wire cipher suite is contained in the security
      * policy, and thus was offered by the client.
      *
-     *= https://tools.ietf.org/rfc/rfc8446#4.1.3
+     *= https://www.rfc-editor.org/rfc/rfc8446#4.1.3
      *# A client which receives a
      *# cipher suite that was not offered MUST abort the handshake with an
      *# "illegal_parameter" alert.
      *
-     *= https://tools.ietf.org/rfc/rfc8446#4.1.4
+     *= https://www.rfc-editor.org/rfc/rfc8446#4.1.4
      *# A client which receives a cipher suite that was not offered MUST
      *# abort the handshake.
      *
-     *= https://tools.ietf.org/rfc/rfc8446#4.1.4
+     *= https://www.rfc-editor.org/rfc/rfc8446#4.1.4
      *# Upon receipt of a HelloRetryRequest, the client MUST check the
      *# legacy_version, legacy_session_id_echo, cipher_suite
      **/
@@ -1123,7 +1161,7 @@ int s2n_set_cipher_as_client(struct s2n_connection *conn, uint8_t wire[S2N_TLS_C
     POSIX_ENSURE(cipher_suite->available, S2N_ERR_CIPHER_NOT_SUPPORTED);
 
     /** Clients MUST verify
-     *= https://tools.ietf.org/rfc/rfc8446#section-4.2.11
+     *= https://www.rfc-editor.org/rfc/rfc8446#section-4.2.11
      *# that the server selected a cipher suite
      *# indicating a Hash associated with the PSK
      **/
@@ -1133,7 +1171,7 @@ int s2n_set_cipher_as_client(struct s2n_connection *conn, uint8_t wire[S2N_TLS_C
     }
 
     /**
-     *= https://tools.ietf.org/rfc/rfc8446#4.1.4
+     *= https://www.rfc-editor.org/rfc/rfc8446#4.1.4
      *# Upon receiving
      *# the ServerHello, clients MUST check that the cipher suite supplied in
      *# the ServerHello is the same as that in the HelloRetryRequest and
@@ -1216,7 +1254,7 @@ static int s2n_set_cipher_as_server(struct s2n_connection *conn, uint8_t *wire,
 
     if (s2n_wire_ciphers_contain(renegotiation_info_scsv, wire, count, cipher_suite_len)) {
         /** For renegotiation handshakes:
-         *= https://tools.ietf.org/rfc/rfc5746#3.7
+         *= https://www.rfc-editor.org/rfc/rfc5746#3.7
          *# o  When a ClientHello is received, the server MUST verify that it
          *#    does not contain the TLS_EMPTY_RENEGOTIATION_INFO_SCSV SCSV.  If
          *#    the SCSV is present, the server MUST abort the handshake.
@@ -1224,7 +1262,7 @@ static int s2n_set_cipher_as_server(struct s2n_connection *conn, uint8_t *wire,
         POSIX_ENSURE(!s2n_handshake_is_renegotiation(conn), S2N_ERR_BAD_MESSAGE);
 
         /** For initial handshakes:
-         *= https://tools.ietf.org/rfc/rfc5746#3.6
+         *= https://www.rfc-editor.org/rfc/rfc5746#3.6
          *# o  When a ClientHello is received, the server MUST check if it
          *#    includes the TLS_EMPTY_RENEGOTIATION_INFO_SCSV SCSV.  If it does,
          *#    set the secure_renegotiation flag to TRUE.
@@ -1289,7 +1327,7 @@ static int s2n_set_cipher_as_server(struct s2n_connection *conn, uint8_t *wire,
             }
 
             /**
-             *= https://tools.ietf.org/rfc/rfc8446#section-4.2.11
+             *= https://www.rfc-editor.org/rfc/rfc8446#section-4.2.11
              *# The server MUST ensure that it selects a compatible PSK
              *# (if any) and cipher suite.
              **/
