@@ -29,6 +29,7 @@ struct s2n_fingerprint {
     const struct s2n_fingerprint_method *method;
     struct s2n_client_hello *client_hello;
     struct s2n_hash_state hash;
+    struct s2n_stuffer workspace;
 };
 
 struct s2n_fingerprint_hash {
@@ -38,15 +39,19 @@ struct s2n_fingerprint_hash {
 };
 S2N_RESULT s2n_fingerprint_hash_add_char(struct s2n_fingerprint_hash *hash, char c);
 S2N_RESULT s2n_fingerprint_hash_add_str(struct s2n_fingerprint_hash *hash, const char *str, size_t str_size);
+S2N_RESULT s2n_fingerprint_hash_add_bytes(struct s2n_fingerprint_hash *hash, const uint8_t *b, size_t size);
 S2N_RESULT s2n_fingerprint_hash_digest(struct s2n_fingerprint_hash *hash, uint8_t *out, size_t out_size);
 bool s2n_fingerprint_hash_do_digest(struct s2n_fingerprint_hash *hash);
 
 struct s2n_fingerprint_method {
     s2n_hash_algorithm hash;
     uint32_t hash_str_size;
-    S2N_RESULT (*fingerprint)(struct s2n_client_hello *ch,
+    S2N_RESULT (*fingerprint)(struct s2n_fingerprint *fingerprint,
             struct s2n_fingerprint_hash *hash, struct s2n_stuffer *output);
 };
 extern struct s2n_fingerprint_method ja3_fingerprint;
+extern struct s2n_fingerprint_method ja4_fingerprint;
 
 bool s2n_is_grease_value(uint16_t val);
+S2N_RESULT s2n_fingerprint_parse_extension(struct s2n_stuffer *input, uint16_t *iana);
+S2N_RESULT s2n_fingerprint_get_legacy_version(struct s2n_client_hello *ch, uint16_t *version);
